Module cnma

Module cnma 

Loading and saving cnm config files

Structs

Cnma
CNMA file. Holds generic configuration of the game and resource locations.
MaxPowerDef
A power defintion for a particular skin id, or any id. These are activated when hitting the MaxPower trigger in game and modify your player stats.
ResourceId
Used in the SoundID and the MusicID modes to specify what file a sound is related to and its related ID.

Enums

Error
Errors when dealing with CNMA files
MaxPowerAbility
A ability activated on a double jump.
Mode
What section/mode contents there are