pub enum Error {
CantOpenFile {
source: Error,
},
NotCnmaFile,
CorruptedEntry(usize),
NoMode,
Corrupted(String),
}Expand description
Errors when dealing with CNMA files
Variants
CantOpenFile
Fields

source: ErrorThe actuall std::io::Error from reading/writing to the file.
NotCnmaFile
The file is not a CNM config file.
CorruptedEntry(usize)
There was a corrupted entry at the line specified
NoMode
There was an mode field but it had no mode name
Corrupted(String)
The file is corrupted because of the string inside of the tuple variant