pub enum MaxPowerAbility {
DoubleJump,
Flying,
DropShield,
MarioBounce,
}Expand description
A ability activated on a double jump.
Variants
DoubleJump
Basic double jump
Flying
Basic flying ability akin to the normal wings power up
DropShield
Activates a sheild once you hit the ground for a short moment of time
MarioBounce
Allows you to bounce on enemies but not hurt them.