Cnma

Struct Cnma 

pub struct Cnma {
    pub modes: Vec<Mode>,
}
CNMA file. Holds generic configuration of the game and resource locations.

  • Sound and music ids and file paths
  • Lua scripting code
  • Custom upgrade/powers
  • The order of the level select menu

Fields

modes: Vec<Mode>

Vector of the sections of the file.

Implementations

Source

impl Cnma

pub fn from_file<P: AsRef<Path>>(path: P) -> Result<Self, Error>

Load a Cnma config from a file

pub fn from_string(s: &str) -> Result<Self, Error>

Load a Cnma config from a string

pub fn save<P: AsRef<Path>>(&self, path: P) -> Result<(), Error>

Saves the cnma file to the path specified, creates the file if it doesn’t exist and overwrites it if it does.