pub struct MaxPowerDef {
pub id: u8,
pub speed: f32,
pub jump: f32,
pub gravity: f32,
pub hpcost: f32,
pub strength: f32,
pub ability: Option<MaxPowerAbility>,
}Expand description
A power defintion for a particular skin id, or any id. These are activated when hitting the MaxPower trigger in game and modify your player stats.
Fields
id: u8The skin id for this power definition
speed: f32The speed multiplier
jump: f32Jump multiplier
gravity: f32Gravity multiplier
hpcost: f32How many hp points are removed per second while the power is active
strength: f32The strength multiplier
ability: Option<MaxPowerAbility>An optional double jump ability.