pub enum EntryData {
Null,
Dummy,
I32(Vec<i32>),
U32(Vec<u32>),
U8(Vec<u8>),
U16(Vec<u16>),
F32(Vec<f32>),
Rect(Vec<Rect>),
}Expand description
A CNM LParse entry
Variants
Null
Null
Dummy
Dummy, different null means unused, dummy is used but has no data field
I32(Vec<i32>)
Array of i32s
U32(Vec<u32>)
Array of u32s
U8(Vec<u8>)
Array of u8s
U16(Vec<u16>)
Array of u16s
F32(Vec<f32>)
Array of f32s
Rect(Vec<Rect>)
Array of Rects
Implementations
Sourceimpl EntryData
impl EntryData
Sourcepub fn get_entry_len(&self) -> usize
pub fn get_entry_len(&self) -> usize
Gets the length of the entry
Sourcepub fn try_get_i32(&self) -> Result<&[i32], Error>
pub fn try_get_i32(&self) -> Result<&[i32], Error>
Returns a refrence to a slice of the type specified or and error of UnexpectedEntryType if it’s not the same as the type.
Sourcepub fn try_get_u32(&self) -> Result<&[u32], Error>
pub fn try_get_u32(&self) -> Result<&[u32], Error>
Returns a refrence to a slice of the type specified or and error of UnexpectedEntryType if it’s not the same as the type.
Sourcepub fn try_get_u8(&self) -> Result<&[u8], Error>
pub fn try_get_u8(&self) -> Result<&[u8], Error>
Returns a refrence to a slice of the type specified or and error of UnexpectedEntryType if it’s not the same as the type.
Sourcepub fn try_get_u16(&self) -> Result<&[u16], Error>
pub fn try_get_u16(&self) -> Result<&[u16], Error>
Returns a refrence to a slice of the type specified or and error of UnexpectedEntryType if it’s not the same as the type.
Sourcepub fn try_get_f32(&self) -> Result<&[f32], Error>
pub fn try_get_f32(&self) -> Result<&[f32], Error>
Returns a refrence to a slice of the type specified or and error of UnexpectedEntryType if it’s not the same as the type.
Sourcepub fn try_get_rect(&self) -> Result<&[Rect], Error>
pub fn try_get_rect(&self) -> Result<&[Rect], Error>
Returns a refrence to a slice of the type specified or and error of UnexpectedEntryType if it’s not the same as the type.
Sourcepub fn try_get_i32_mut(&mut self) -> Result<&mut Vec<i32>, Error>
pub fn try_get_i32_mut(&mut self) -> Result<&mut Vec<i32>, Error>
Returns a refrence to a mut slice of the type specified or and error of UnexpectedEntryType if it’s not the same as the type.
Sourcepub fn try_get_u32_mut(&mut self) -> Result<&mut Vec<u32>, Error>
pub fn try_get_u32_mut(&mut self) -> Result<&mut Vec<u32>, Error>
Returns a refrence to a mut slice of the type specified or and error of UnexpectedEntryType if it’s not the same as the type.
Sourcepub fn try_get_u8_mut(&mut self) -> Result<&mut Vec<u8>, Error>
pub fn try_get_u8_mut(&mut self) -> Result<&mut Vec<u8>, Error>
Returns a refrence to a mut slice of the type specified or and error of UnexpectedEntryType if it’s not the same as the type.
Sourcepub fn try_get_u16_mut(&mut self) -> Result<&mut Vec<u16>, Error>
pub fn try_get_u16_mut(&mut self) -> Result<&mut Vec<u16>, Error>
Returns a refrence to a mut slice of the type specified or and error of UnexpectedEntryType if it’s not the same as the type.