Error

Enum Error 

pub enum Error {
    CantOpenFile {
        source: Error,
    },
    NotLParseFile,
    UnknownVersion(u32),
    Corrupted(String),
    EntryCorrupted(String, usize),
    UnknownEntryType(String, usize, u32),
    EntryOverflow(u32, usize, usize),
    MismatchedVersions(u32, u32),
    CannotFindEntry(String),
    UnexpectedEntryType(u32, u32),
}
Error when loading/saving lparse files

Variants



CantOpenFile

Couldn’t open the file for reading and writing

Fields

source: Error

The actuall std::io::Error that came from reading and writing



NotLParseFile

The file being opened is not an CNM Lparse file.



UnknownVersion(u32)

The version specifed can not be loaded by the parser



Corrupted(String)

The lparse file is corrupted due to …



EntryCorrupted(String, usize)

Entry ID {1} (name: {0}) is corrupted



UnknownEntryType(String, usize, u32)

Entry ID {1} (name: {0}) has an unknown type id of {2}



EntryOverflow(u32, usize, usize)

The CNM LParse struct has too many entries



MismatchedVersions(u32, u32)

When loading a level file, the 2 files .cnmb and .cnms have mismatching version ids.



CannotFindEntry(String)

When looking for an entry, it couldn’t find it



UnexpectedEntryType(u32, u32)

When getting a entry you expected data type X but got data type Y