Module level_data

Module level_data 

Enable the “Level Data” feature to parse level data

Modules

cnmb_types
Types of the CNMB file. This includes tile properties, the world tiles, and backgrounds.
cnms_types
Types of the CNMS file. This includes world objects, strings from the world, world title, etc.
consts
Consts used in CNM Online that are also used here (like tile size).

Structs

Duration
Duration of something in ticks. (There are 30 ticks per second in CNM Online, so a Duration of 30 is 1 second). Negative values have uses in very specific and special cases in CNM Online. Mostly is 0 or above though.
LevelData
The overarching level data structure. Holds everything pertaining to a level in CNM Online.
LevelMetaData
Metadata for this level.
Point
Defines a point for CNM types.
VersionSpecs
Version specs of the level data (seperate from the lparse file version)

Enums

DifficultyRating
Difficulty rating for a level