VersionSpecs

Struct VersionSpecs 

pub struct VersionSpecs { /* private fields */ }
Version specs of the level data (seperate from the lparse file version)

Implementations

Source

impl VersionSpecs

pub fn from_version(version: u32) -> Result<Self, Error>

Creates it from a specific level file version Only current level format in CNM Online is ID 1.

pub fn get_version(&self) -> u32

Version ID

pub fn get_num_teleports(&self) -> usize

Maximum number of teleports supported

pub fn get_num_spawns(&self) -> usize

Maximum number of spawns per mode (there are 2 modes used, 1 unused) Those modes being, player spawns, checkpoints, and an unused mode.

pub fn get_num_spawn_modes(&self) -> usize

Number of spawner modes.

pub fn get_teleport_name_size(&self) -> usize

Maximum size of a teleport name in bytes. All names in CNM Online are ascii.

pub fn get_max_tile_frames(&self) -> usize

Maximum amount of frames an animated tile can have in CNM Online

pub fn get_ending_text_lines(&self) -> usize

Number of text lines saved in CNMS files.

pub fn get_ending_text_line_len(&self) -> usize

The length of each CNMS text line in bytes.

pub fn get_background_layers(&self) -> usize

The maximum amount of background layers this version supports.

pub fn get_title_ending_text_line(&self) -> usize

What text line the title is on in this version

pub fn get_preview_tile_index(&self) -> usize

What tile index controls the preview for a level in this version