pub struct LParse {
pub entries: HashMap<String, EntryData>,
/* private fields */
}
The entries present in the lparse file
Create an lparse file from the version id
Load an lparse file from the path
Load an lparse file from memory
Save to a file path. Creates it if it isn’t there and overwrites it if it is.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.