Module cnmo_parse::cnma
source · Expand description
Loading and saving cnm config files
Structs
- CNMA file. Holds generic configuration of the game and resource locations.
- A power defintion for a particular skin id, or any id. These are activated when hitting the MaxPower trigger in game and modify your player stats.
- Used in the SoundID and the MusicID modes to specify what file a sound is related to and its related ID.
Enums
- Errors when dealing with CNMA files
- A ability activated on a double jump.
- What section/mode contents there are