Enum cnmo_parse::cnma::Mode
source · pub enum Mode {
MusicIds(Vec<ResourceId>),
SoundIds(Vec<ResourceId>),
MusicVolumeOverride,
LevelSelectOrder(Vec<String>),
MaxPowerDef(MaxPowerDef),
LuaAutorunCode(String),
}Expand description
What section/mode contents there are
Variants
MusicIds(Vec<ResourceId>)
Music Resource Ids
SoundIds(Vec<ResourceId>)
Sound Resource Ids
MusicVolumeOverride
A deprecated CNM Online section
LevelSelectOrder(Vec<String>)
The order of levels on the level select menu, same order as the strings in the vector here.
MaxPowerDef(MaxPowerDef)
A power defintion for a particular skin
LuaAutorunCode(String)
Code run at the beginning of the game, certain function names will run as hooks for object code, etc.