pub struct Cnma {
pub modes: Vec<Mode>,
}
CNMA file. Holds generic configuration of the game and resource
locations.
- Sound and music ids and file paths
- Lua scripting code
- Custom upgrade/powers
- The order of the level select menu
Vector of the sections of the file.
Load a Cnma config from a file
Load a Cnma config from a string
Saves the cnma file to the path specified, creates the file if it doesn’t
exist and overwrites it if it does.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.