Struct cnmo_parse::cnma::ResourceId
source · pub struct ResourceId {
pub id: u32,
pub path: String,
}Expand description
Used in the SoundID and the MusicID modes to specify what file a sound is related to and its related ID.
Fields
id: u32The ID for CNM Online. If 2 are the same, the last is used and a memory leak occurs.
path: StringThe path to the file in question. It is relative based on the exe’s directory and doesn’t need a “./” at the start.